+function ($) {
  'use strict';

  // MODAL CLASS DEFINITION
  // ======================

  var Modal = function (element, options) {
    this.options   = options
    this.$element  = $(element)
    this.$backdrop =
    this.isShown   = null

    if (this.options.remote) {
      this.$element
        .find('.modal-content')
        .load(this.options.remote, $.proxy(function () {
          this.$element.trigger('loaded.bs.modal')
        }, this))
    }
  }

  Modal.DEFAULTS = {
    backdrop: true,
    keyboard: true,
    show: true
  }

  Modal.prototype.toggle = function (_relatedTarget) {
    return this[!this.isShown ? 'show' : 'hide'](_relatedTarget)
  }

  Modal.prototype.show = function (_relatedTarget) {
    var that = this
    var e    = $.Event('show.bs.modal', { relatedTarget: _relatedTarget })

    this.$element.trigger(e)

    if (this.isShown || e.isDefaultPrevented()) return

    this.isShown = true

   // this.escape()

    this.$element.on('click.dismiss.bs.modal', '[data-dismiss="modal"]', $.proxy(this.hide, this))

    this.backdrop(function () {
      var transition = $.support.transition && that.$element.hasClass('fade')

      if (!that.$element.parent().length) {
        that.$element.appendTo(document.body) // don't move modals dom position
      }

      that.$element
        .show()
        .scrollTop(0)

      if (transition) {
        that.$element[0].offsetWidth // force reflow
      }

      that.$element
        .addClass('in')
        .attr('aria-hidden', false)

      that.enforceFocus()

      var e = $.Event('shown.bs.modal', { relatedTarget: _relatedTarget })

      transition ?
        that.$element.find('.modal-dialog') // wait for modal to slide in
          .one($.support.transition.end, function () {
            that.$element.focus().trigger(e)
          })
          .emulateTransitionEnd(300) :
        that.$element.focus().trigger(e)
    })
  }

  Modal.prototype.hide = function (e) {
    if(e) e.preventDefault();

    e = $.Event('hide.bs.modal')

    this.$element.trigger(e)

    if (!this.isShown || e.isDefaultPrevented()) return

    this.isShown = false

    this.escape()

    $(document).off('focusin.bs.modal')

    this.$element
      .removeClass('in')
      .attr('aria-hidden', true)
      .off('click.dismiss.bs.modal')

    $.support.transition && this.$element.hasClass('fade') ?
      this.$element
        .one($.support.transition.end, $.proxy(this.hideModal, this))
        .emulateTransitionEnd(300) :
      this.hideModal()
  }

  Modal.prototype.enforceFocus = function () {
    $(document)
      .off('focusin.bs.modal') // guard against infinite focus loop
      .on('focusin.bs.modal', $.proxy(function (e) {
        if (this.$element[0] !== e.target && !this.$element.has(e.target).length) {
          this.$element.focus()
        }
      }, this))
  }

  Modal.prototype.escape = function () {
    if (this.isShown && this.options.keyboard) {
      this.$element.on('keyup.dismiss.bs.modal', $.proxy(function (e) {
        e.which == 27 && this.hide()
      }, this))
    } else if (!this.isShown) {
      this.$element.off('keyup.dismiss.bs.modal')
    }
  }

  Modal.prototype.hideModal = function () {
    var that = this
    this.$element.hide()
    this.backdrop(function () {
      that.removeBackdrop()
      that.$element.trigger('hidden.bs.modal')
    })
  }

  Modal.prototype.removeBackdrop = function () {
    this.$backdrop && this.$backdrop.remove()
    this.$backdrop = null
  }

  Modal.prototype.backdrop = function (callback) {
    var animate = this.$element.hasClass('fade') ? 'fade' : ''

    if (this.isShown && this.options.backdrop) {
      var doAnimate = $.support.transition && animate

      this.$backdrop = $('<div class="modal-backdrop ' + animate + '" />')
        .appendTo(document.body)

      /*this.$element.on('click.dismiss.bs.modal', $.proxy(function (e) {
        if (e.target !== e.currentTarget) return
        this.options.backdrop == 'static'
          ? this.$element[0].focus.call(this.$element[0])
          : this.hide.call(this)
      }, this))*/

      if (doAnimate) this.$backdrop[0].offsetWidth // force reflow

      this.$backdrop.addClass('in')

      if (!callback) return

      doAnimate ?
        this.$backdrop
          .one($.support.transition.end, callback)
          .emulateTransitionEnd(150) :
        callback()

    } else if (!this.isShown && this.$backdrop) {
      this.$backdrop.removeClass('in')

      $.support.transition && this.$element.hasClass('fade') ?
        this.$backdrop
          .one($.support.transition.end, callback)
          .emulateTransitionEnd(150) :
        callback()

    } else if (callback) {
      callback()
    }
  }


  // MODAL PLUGIN DEFINITION
  // =======================

  var old = $.fn.modal

  $.fn.modal = function (option, _relatedTarget) {
    return this.each(function () {
      var $this   = $(this)
      var data    = $this.data('bs.modal')
      var options = $.extend({}, Modal.DEFAULTS, $this.data(), typeof option == 'object' && option)

      if (!data) $this.data('bs.modal', (data = new Modal(this, options)))
      if (typeof option == 'string') data[option](_relatedTarget)
      else if (options.show) data.show(_relatedTarget)
    })
  }

  $.fn.modal.Constructor = Modal


  // MODAL NO CONFLICT
  // =================

  $.fn.modal.noConflict = function () {
    $.fn.modal = old
    return this
  }


  // MODAL DATA-API
  // ==============

  $(document).on('click.bs.modal.data-api', '[data-toggle="modal"]', function (e) {
    var $this   = $(this)
    var href    = $this.attr('href')
    var $target = $($this.attr('data-target') || (href && href.replace(/.*(?=#[^\s]+$)/, ''))) //strip for ie7
    var option  = $target.data('bs.modal') ? 'toggle' : $.extend({ remote: !/#/.test(href) && href }, $target.data(), $this.data())

    if ($this.is('a')) e.preventDefault()

    $target
      .modal(option, this)
      .one('hide', function () {
        $this.is(':visible') && $this.focus()
      })  
  })

  $(document)
    .on('show.bs.modal', '.modal', function () { $(document.body).addClass('modal-open') })
    .on('hidden.bs.modal', '.modal', function () { $(document.body).removeClass('modal-open') })

}(jQuery);
jQuery(document).ready(function ($) {
        var used_img = [];
        $( "#pc-part-list" ).disableSelection();
        $( "#pc-part-list" ).sortable({
          placeholder: "ui-state-highlight",
          update: function( event, ui ) {
              var global_part_tmp=new Object();
              var new_preview="";
              $("#pc-part-list > li > a").each(function( i ) {  
                 var data_id=$(this).data('id');
                 global_part_tmp[data_id]=global_part[data_id];
                 new_preview=new_preview+"<img id='"+data_id+"_preview' src='"+global_part[data_id]["defaul_img_url"]+"'>";
              });
              global_part=global_part_tmp;
              $("#pc_preview").html(new_preview);
//              console.log(global_part_tmp);
//              console.log(global_part);
          }
        });
	
	//$('.admin-help').tooltip();
	
	var global_part=new Object();
	var global_default_layer="";
       $(document).on('click','#pc_add_group',function(){
       	if($(this).val()==message_array.cancel){
       		$('#add-group-container').hide();
       		$(this).val(message_array.add_cat_image);
       	}else{
       		$('#add-group-container').show();
       		$(this).val(message_array.cancel);
       	}
       })
       .on('click','#pc-add-groupe-save',function(){
       		var categ_name=$('#pc-add-groupe-name').attr("value");
       	if(categ_name.length!=0){
       		add_category(categ_name);
       		$('#pc-add-groupe-name').val("");
       		$('#add-group-container').hide();
       		$('#pc_add_group').val(message_array.add_cat_image);
       	}
       })
       .on('click','#pc_add_image',function(){
       	var uploader=wp.media({
                    title:message_array.add_image,
                    multiple:true
            }).on('select',function(){
                    var selection=uploader.state().get('selection')
                    selection.map(
                            function(attachment){
                                    attachment=attachment.toJSON();
                                   
                                    if(attachment.subtype!="png"){
                                    	alert(message_array.image_type_error);
                                    }else if( in_array(used_img, attachment.id)){
                                        alert(message_array.image_used);
                                    }else{
                                    	insert_part_image(add_image(attachment.id,attachment.url,"","","","",""),"","")
                                        used_img.push(attachment.id);
                                    	
                                    }
                            }
                    )
            })
            .open();
    		return false;
       })
       .on('click','.pc-category-addimg',function(){
       	var $that=$(this);
       	var uploader=wp.media({
                    title:message_array.add_image,
                    multiple:true
            }).on('select',function(){
                    var selection=uploader.state().get('selection')
                    selection.map(
                            function(attachment){
                                    attachment=attachment.toJSON();
                                    if(attachment.subtype!="png"){
                                    	alert(message_array.image_type_error);
                                    }else if( in_array(used_img, attachment.id)){
                                        alert(message_array.image_used);
                                    }
                                    else{
                                        add_category_image(attachment.id,attachment.url,"","",$that,"",'','',"")
                                        used_img.push(attachment.id);
                                    }
                            }
                    )
            })
            .open();
    		return false;
       })
       .on('click','.close-addpop',function(){
       	var $that=$(this).parent();
        var removed_img_id = $that.find('.pc-img').data('data-id');
        if ($.isArray(removed_img_id)){
            removed_img_id.each(function(){
                var index = used_img.indexOf(this);
                if ( index > -1) {
                    used_img.splice(index, 1);
                }
            });
        }else{
            var index = used_img.indexOf(this);
            used_img.splice(index, 1);
        }
         
        
       	$(this).parent().fadeOut(300,function(){$that.remove()});
       })
       .on('click','.pc-image-add-icon',function(){
       	var $that=$(this);
       	var uploader=wp.media({
                    title:message_array.add_icon,
                    multiple:false
            }).on('select',function(){
                    var selection=uploader.state().get('selection')
                    selection.map(
                            function(attachment){
                                    attachment=attachment.toJSON();
                                    $that.parent().find('.icon-msg-err').remove();
                                    if($that.parent().find('.pc-img-icon').length!=0){
                                    	$that.parent().find('.pc-img-icon').attr('data-id',attachment.id).attr('src',attachment.url)
                                    }else{
                                    	$that.parent().append("<img class='pc-img-icon' width='24' height='24' data-id='"+attachment.id+"' src='"+attachment.url+"'>")
                            			$that.val(message_array.change_icon).addClass(message_array.changes)
                                    }
                                    
                            }
                    )
            })
            .open();
    		return false;
       })
       .on('click','.pc-edit-img',function(){
       	var $that=$(this);
       	var uploader=wp.media({
                    title:message_array.add_icon,
                    multiple:false
            }).on('select',function(){
                    var selection=uploader.state().get('selection')
                    selection.map(
                            function(attachment){
                                    attachment=attachment.toJSON();
                                    if(attachment.subtype!="png"){
                                    	alert(message_array.image_type_error);
                                    }else if( in_array(used_img, attachment.id)){
                                        alert(message_array.image_used);
                                    }
                                    else{
                                        if($that.parent().find('.pc-img').length!=0){
                                            $that.parent().find('.pc-img').attr('data-id',attachment.id).attr('src',attachment.url)
                                            $that.parent().find("input[type='radio']").attr('data-src',attachment.url).val(attachment.id)

                                        }
                                    	
                                    }
                                    
                                    
                            }
                    )
            })
            .open();
    		return false;
       })
       .on('click','.hide-show',function(){
       	if($(this).hasClass('hide-ul')){
       		$(this).parent().find(".pc-category-addimg").show();
       		$(this).removeClass('hide-ul').parent().find("ul").show(100);
       	}else{
       		$(this).parent().find(".pc-category-addimg").hide();
       		$(this).addClass('hide-ul').parent().find("ul").hide(100)
       	}
       })
       .on('click','#save_part_btn',function(){
            if($( "#pc-images-list li img" ).length==0){
                    alert(message_array.please_add_image);
                    //reset_modal();
                    //$('#subscriber_modal').modal('hide')
                    return;
            }
            var pc_partname=$('#pc-partname').val();
            var flag=1;
            var part=new Object();
            var imgs=new Object();
            var categ_img=new Object();
            if(pc_partname.trim().length==0){
                    $('#pc-partname').addClass('field-error');
                    flag*=0;
            }else{
                    $('#pc-partname').removeClass('field-error');
            }

            var ct=0;
            $( "#pc-images-list>ul>li" ).each(function( i ) {       		
                    if(!$(this).hasClass('pc-category')){
                            var img=get_img_line($(this));
                            if(img!=false){
                                    imgs[ct]=img;
                            }else{
                                    flag*=0;
                            }

                    }else{
                            var categ=new Object();
                            categ['name']=$(this).find(".pc-category-container .pc-catlabel").val().trim();
                            var sub_categ=new Object();
                            var ct_2=0;
                                    $( this ).find(".pc-category-container ul li").each(function( i ) { 
                                            var img=get_img_line($(this));
                                            if(img!=false){
                                                    sub_categ[ct_2]=img;
                                            }else{
                                                    flag*=0;
                                            } 
                                            ct_2++;
                                    });
                                    categ['img']=sub_categ;
                                    categ_img[ct]=categ;

                    }
                    ct++;
            });
            if(flag==1){
                    /*if($('.wpb-layer-img img').length==0){
                            alert('Please add layer icon')
                            return;
                    }*/

                    part['name']=pc_partname;
                    part['mandatory']=$("#part_mandatory:checked").length;
                    part['layer_icon']= ($(".wpb-layer-img img").length==1)?$(".wpb-layer-img img").attr('src'):"0";

                    $defaul_img=$("#pc-images-list input[type='radio']:checked");
                    var defaul_img_url="",defaul_img_url="";
                    if($defaul_img.length!=0){
                            part['defaul_img']=$defaul_img.attr("value");
                            defaul_img_url=$defaul_img.attr('data-src');
                            part['defaul_img_url']=defaul_img_url;

                    }else{
                            part['defaul_img']=$("#pc-images-list input[type='radio']:first-child").attr("value");
                            defaul_img_url=$("#pc-images-list input[type='radio']:first-child").attr('data-src');
                            part['defaul_img_url']=defaul_img_url;
                    }
                    part['img_s']=imgs;
                    part['category']=categ_img;
                    part_id=($(this).attr('data-id')!="")?$(this).attr('data-id'):uniqid("part");
                    global_part[part_id]=part;
                    var data_id=$('#save_part_btn').attr('data-id');
                    if(data_id=="" || data_id==undefined){
                            alert(message_array.layer_added);
                    }else{
                            alert(message_array.layer_updated);
                    } 
                    $(this).attr('data-id',"");
                    add_part_in_list(defaul_img_url,part_id);

            }else{
                    //alert('Error !')
            }
       	
       })      
       .on('click','.edit_part_grp',function(){
            var part_id=$(this).parent().find('a').attr('data-id');
            //var part_id=$(this).attr('data-id');
            //console.log(get_used_img(global_part));
            var part=global_part[part_id];
            var part_name=part['name'];
            var default_img_url=part['defaul_img_url'];
            var default_img=part['defaul_img'];
            var mandatory=part['mandatory'];
            var layer_icon=part['layer_icon'];
            var categories=part['category'];
            var images=part['img_s'];
            var img_ouput="";
            if(parseInt(mandatory)==1){
                    $('#part_mandatory').attr('checked',"checked");
            }
            if(layer_icon!="0")
            $('.wpb-layer-img').html('<span>&times;</span><img width="70" data-id="45" src="'+layer_icon+'">');
            $('#add_layer_icon').text(message_array.change_layer_icon);

            $('#save_part_btn').attr("data-id",part_id);
            $('#pc-partname').val(part_name.replace("\\'","'"));

            for(var key in images){
                            var image = images[key];
                            img_ouput+=add_image(image['img_id'],image['img_url'],image['img_name'],image['img_price'],image['icon_id'],image['icon_url'],image['img_key'],default_img);
                    }
                    var categories_output="";
                    for(var i in categories){

                            var categorie = categories[i];
                            var groupe_name=categorie['name'];
                            var category_imgs=categorie['img'];
                            var category_out="";
                            for(var j in category_imgs){
                                    var category_img=category_imgs[j];
                                    category_out+=add_category_image(category_img['img_id'],category_img['img_url'],category_img['img_name'],category_img['img_price'],"",category_img['img_key'],category_img['icon_id'],category_img['icon_url'],default_img);
                            }
                            categories_output+=get_group(groupe_name,category_out);

                    }

                    img_ouput+=categories_output;
                    insert_part_image(img_ouput,2);
                    $('#subscriber_modal').modal('show');
       })
       .on('click','#save_data',function(){
       		if($('#group_part_name').val().trim().length==0){
       			$('#group_part_name').addClass('field-error');
       			alert(message_array.enter_group_layer_name);
       		}else{
       			if($('#pc_preview img').length==0){
       				alert(message_array.add_layer_image);
       				return;
       			}else{
       				$('#group_part_name').removeClass('field-error');
       				insert_part(); 
       			}     
       		}
       })
       .on('click','.pc_delete_part',function(e){
       	e.preventDefault();
       	if(confirm(message_array.confirm_part_delete)==false) return;
       		var part_id=$(this).attr('data-id');
       		var $that=$(this);
       		 $.post( ajaxurl,
		              {action: "wpb_delete_part", part_id: part_id},
		                function(data) {
		                		$that.parent().parent().fadeOut(200,function(){$that.parent().parent().remove();}) ;
		                }
	            );
       		
       })
       .on('click','.remove_part_grp',function(e){
       	e.preventDefault();
       	if(confirm(message_array.confirm_layer_group_delete)==false) return;
	       	var $this=$(this);
	       	var part_id=$this.parent().find('a').attr('data-id');
	       	delete  global_part[part_id];
			$this.parent().fadeOut(200,function(){$this.parent().remove();});
		
			$('#'+part_id+"_preview").remove();   
       })
        .on('click','#add_part',function(e){
       		reset_modal();
       		$('#subscriber_modal').modal('show');
       })
       .on('click','#add_layer_icon',function(){
       	var $that=$(this);
       	var uploader=wp.media({
                    title:"Add Icon",
                    multiple:false
            }).on('select',function(){
                    var selection=uploader.state().get('selection')
                    selection.map(
                            function(attachment){
                                    attachment=attachment.toJSON();
                                    $that.parent().find('.icon-msg-err').remove();
                                    if($('.wpb-layer-img img').length!=0){
                                    	$('.wpb-layer-img').find('img').attr('data-id',attachment.id).attr('src',attachment.url)
                                    }else{
                                    	$('.wpb-layer-img').append("<span>&times;</span><img width='70' data-id='"+attachment.id+"' src='"+attachment.url+"'>")
                                    }
                                    $('#add_layer_icon').text(message_array.change_layer_icon);
                            }
                    )
            })
            .open();
    		return false;
       }) .on('click','.wpb-layer-img span',function(){
       	var $that=$(this);
       		$that.parent().html('');
    		return false;
       });;
       
       
       function insert_part(){
       	var part_id=($('#pc_part_id').length==1)?$('#pc_part_id').val():"";
       		 $.post( ajaxurl,
		              {action: "wpb_add_data", part_id: part_id,data:global_part,name:$('#group_part_name').val().trim()},
		                function(data) {
		                	$(window).unbind('beforeunload');
		                		location.href=data;
		                }
	            );
	            
       }
       
		 if($("#pc-part-title").length!=0) {
		 	 $(window).bind('beforeunload', function(event) {
			 	if($('#pc_preview img').length!=0){
					return message_array.close_msg;
				}else{
					
				}
			 	
			});
		 }
		
       
       
       function get_group(category_name,html){
       	var out_put="";
       	out_put="<li class='pc-category'><span title='Hide' class='hide-show'></span><span title='"+message_array.deletes+"' class='close-addpop'>&times;</span><div class='pc-category-container'>";
       	out_put+='<input title="Click to edit" type="text" value="'+category_name.replace("\\'","'")+'" class="pc-catlabel">';
       		out_put+="<ul>"+html+"</ul>";
       			out_put+="<input type='button' value='"+message_array.add_image+"' class='button pc-category-addimg'/></div></li>";
       			return out_put;
       }
       
       
       function add_category(category_name){
	       	var out_put="";
	       	if($('#pc-images-list>ul').length==0){
       			$('#pc-images-list').append("<ul></ul>");
       		}
	       	out_put="<li class='pc-category'><span title='"+message_array.hide+"' class='hide-show'></span><span title='Delete' class='close-addpop'>&times</span><div class='pc-category-container'><input title='Click to edit' type='text' value="+category_name+" class='pc-catlabel'>";
	       	out_put+="<ul></ul>";
	       	out_put+="<input type='button' value='"+message_array.add_image+"' class='button pc-category-addimg'/></div></li>";
                $('#pc-images-list>ul').append(out_put);
                $( "#pc-images-list > ul" ).disableSelection();
                $( "#pc-images-list > ul" ).sortable({placeholder: "ui-state-highlight"});
                $( ".pc-category-container > ul" ).disableSelection();
                $( ".pc-category-container > ul" ).sortable({placeholder: "ui-state-highlight"});
       }
       
        

       
        function get_img_line($selector){       	
       			var img_id,icon_id,img_name,img_price,flag=1,img_url,icon_url;
       			img_key=$selector.find('.img-key').val();
       			img_name=$selector.find('.pc-image-name').val().trim();
       			img_price=$selector.find('.pc-image-price').val().trim();
       			img_id=$selector.find('.pc-img').attr('data-id');
       			img_url=$selector.find('.pc-img').attr('src');
       			icon_id=$selector.find('.pc-img-icon').attr('data-id');
       			icon_url=$selector.find('.pc-img-icon').attr('src');/*
       			icon_id= ($selector.find('.pc-img-icon').length>0)?$selector.find('.pc-img-icon').attr('data-id'):0;
       			icon_url= ($selector.find('.pc-img-icon').length>0)?$selector.find('.pc-img-icon').attr('src'):0;*/
       			if(img_name.length==0){
       				$selector.find('.pc-image-name').addClass('field-error');
       				flag*=0;
       			}else{
       				$selector.find('.pc-image-name').removeClass('field-error');
       			}
				
       			/*if(!is_numeric(img_price)){
       				$selector.find('.pc-image-price').addClass('field-error');
       				flag*=0;
       			}else{
       				$selector.find('.pc-image-price').removeClass('field-error');
       			}*/
       			if(!is_numeric(img_price)){
       				img_price='0';
       			}
       			
       			
       			if($selector.find(".pc-img-icon").length==0){
       				if($selector.find(".pc-image-add-icon").parent().find('.icon-msg-err').length==0){
       					$selector.find(".pc-image-add-icon").parent().append("<span class='icon-msg-err'>"+message_array.insert_icon+"</span>");
       				}else{
       					$selector.find(".pc-image-add-icon").parent().find('.icon-msg-err').html(message_array.insert_icon);
       				}
       				
       				flag*=0;
       			}else{
       				$selector.find(".pc-image-add-icon").parent().find(".icon-msg-err").remove();
       			}
       			if(flag==1){
       				return {"img_name":img_name,"img_price":img_price,"img_id":img_id,'icon_id':icon_id,'icon_url':icon_url,'img_url':img_url,"img_key":img_key};
       			}else{
       				return false;
       			}
				
       }
       
       function add_part_in_list(url,part_id){
       	var id=part_id;
       	if($("#"+part_id).length==1){
       		$("#"+part_id).find('img').attr("src",url);
       		$('#'+part_id+"_preview").attr('src',url);
       	}else{
       		var html="<li><span class='remove_part_grp' title='"+message_array.deletes+"'></span><span title='"+message_array.edit+"' class='edit_part_grp'></span><a data-id='"+id+"' id='"+part_id+"'><img  src='"+url+"'></a></li>";
       		$('#pc-part-list').append(html).show();
       		$('#pc_preview').append("<img id='"+part_id+"_preview' src='"+url+"'>");
       	}   
       		   		
       		reset_modal();
       }
       
          function add_category_image(img_id,img_url,img_name,img_price, $that,img_key,icon_id,icon_url,default_img){
       		var out_put="";
       		if(icon_url!=""){
       			icon_img='<img class="pc-img-icon" width="24" height="24" data-id="'+icon_id+'" src="'+icon_url+'">';
	       	}else{
	       		icon_img="";
	       	}
	       		if(default_img!=""){
			       		if(parseInt(default_img)==parseInt(img_id)){
			       			chk=" checked ";
			       		}else{
			       			chk="";
			       		}
			       		
			       	}else{
			       		chk="";
			       	}
       		img_key=(img_key=="")?uniqid():img_key;
       		out_put="<li><span title='"+message_array.deletes+"' class='close-addpop'>&times;</span>";
			out_put+="<img class='pc-img' src='"+img_url+"' data-id='"+img_id+"' />";
                        out_put+='<input type="button" class="button pc-edit-img" value="'+message_array.edit_img+'"/>';
			out_put+="<input type='hidden' class='img-key' value='"+img_key+"'>";
			out_put+='<div class="pc-image-infos">';
			out_put+='<table border="0" cellspacing="5" cellpadding="0">';
			out_put+='<tr><td>'+message_array.names+' : </td><td><input type="text" class="pc-image-name" value="'+img_name.replace("\\'","'")+'"/></td></tr>';
			out_put+='<tr><td>'+message_array.price+' : </td><td><input type="text" class="pc-image-price" value="'+img_price.replace("\\'","'")+'"/></td></tr>';
			out_put+='<tr><td></td><td><label><input type="radio"  data-src="'+img_url+'" value="'+img_id+'" '+chk+'  name="pc-default-img" /></label>'+message_array.defaults+'</td></tr>';
			out_put+='<tr><td></td><td align="right">'+icon_img+'<input type="button" class="button pc-image-add-icon" value="'+message_array.add_icon+'"/></td></tr></table></li>';
       		if($that!=""){
       			$that.parent().find('ul').append(out_put);
       		}else{
       			return out_put;
       		}
       		
       }
       
       
        function add_image(image_id,image_url,img_name,img_price,icon_id,icon_url,img_key,default_img){

       	if(icon_url!=""){
       		icon_img='<img class="pc-img-icon" width="24" height="24" data-id="'+icon_id+'" src="'+icon_url+'">';
       	}else{
       		icon_img="";
       	}
       	
       	if(default_img!=""){
       		if(parseInt(default_img)==parseInt(image_id)){
       			chk=" checked ";
       		}else{
       			chk="";
       		}
       		
       	}else{
       		chk="";
       	}
       	img_key=(img_key=="")?uniqid():img_key;
       	var out_put="";
       		out_put="<li><span title='"+message_array.defaults+"' class='close-addpop'>&times;</span>";
			out_put+="<img class='pc-img' src='"+image_url+"' data-id='"+image_id+"' />";
                        out_put+='<input type="button" class="button pc-edit-img" value="'+message_array.edit_img+'"/>';
			out_put+="<input class='img-key' value='"+img_key+"' type='hidden'>";
			out_put+='<div class="pc-image-infos">';
			out_put+='<table border="0" cellspacing="5" cellpadding="0">';
			out_put+='<tr><td>'+message_array.names+' : </td><td><input type="text" class="pc-image-name" value="'+img_name.replace("\\'","'")+'"/></td></tr>';
			out_put+='<tr><td>'+message_array.price+' : </td><td><input type="text" class="pc-image-price" value="'+img_price.replace("\\'","'")+'"/></td></tr>';
			out_put+='<tr><td></td><td><label><input type="radio" '+chk+'   data-src="'+image_url+'" value="'+image_id+'" name="pc-default-img" /></label>'+message_array.defaults+'</td></tr>';
			out_put+='<tr><td></td><td align="right">'+icon_img+'<input type="button" class="button pc-image-add-icon" value="'+message_array.add_icon+'"/></td></tr></table></li>';
       		if($('#pc-images-list>ul').length==0){
       			$('#pc-images-list').append("<ul></ul>");
       		}
       		return out_put;
       }
  
       
       
      function reset_modal(){
      	$('#subscriber_modal').modal('hide').find('.modal-body #pc-images-list').html('');
       		$('#pc-partname').val('');
       		$('#add-group-container').hide();
       		$('#pc-add-groupe-name').val('');
       		$('#pc_add_group').val(message_array.add_cat_image);
       		$('#save_part_btn').attr('data-id',"");
       		$(".wpb-layer-img").html('');
       		$('#add_layer_icon').text(message_array.add_layer_icon);
      }
       
       function insert_part_image(html,type){
	       	if($('#pc-images-list>ul').length==0){
	       		$('#pc-images-list').append("<ul></ul>");
	       	}
	       	if(type==2){
	       		$('#pc-images-list>ul').html(html); 
	       	}else{
	       		$('#pc-images-list>ul').append(html);
	       	}
                $( "#pc-images-list > ul" ).disableSelection();
                $( "#pc-images-list > ul" ).sortable({placeholder: "ui-state-highlight"});
                $( ".pc-category-container > ul" ).disableSelection();
                $( ".pc-category-container > ul" ).sortable({placeholder: "ui-state-highlight"});
	       	
	       	
       }
       
       
       
             
      
  		load_editor();
  		function load_editor(){
  			if(pc_active_part=="") return;
  			global_part=pc_active_part;
                        used_img = get_used_img(global_part);
  			for(var part_key in global_part){
  				var part_id=part_key;
  				var part=global_part[part_id];
  				var category_image= part['category'];
  				var images= part['img_s'];	
  				var mandatory=part['mandatory'];
  				var defaul_img=part['mandatory'];
  				var defaul_img_url=part['defaul_img_url'];
  				add_part_in_list(defaul_img_url,part_id);
			}
			$('#pc-part-container').append('<span>'+message_array.drag_drop_msg+'</span>');
  		}
       
		
		function uniqid(prefix, more_entropy) {


  if (typeof prefix === 'undefined') {
    prefix = '';
  }

  var retId;
  var formatSeed = function(seed, reqWidth) {
    seed = parseInt(seed, 10)
      .toString(16); // to hex str
    if (reqWidth < seed.length) { 
      return seed.slice(seed.length - reqWidth);
    }
    if (reqWidth > seed.length) { 
      return Array(1 + (reqWidth - seed.length))
        .join('0') + seed;
    }
    return seed;
  };

  if (!this.php_js) {
    this.php_js = {};
  }
  if (!this.php_js.uniqidSeed) {
    this.php_js.uniqidSeed = Math.floor(Math.random() * 0x75bcd15);
  }
  this.php_js.uniqidSeed++;

  retId = prefix; 
  retId += formatSeed(parseInt(new Date()
    .getTime() / 1000, 10), 8);
  retId += formatSeed(this.php_js.uniqidSeed, 5); 
  if (more_entropy) {
    retId += (Math.random() * 10)
      .toFixed(8)
      .toString();
  }

  return retId;
}


function is_numeric(mixed_var) {
	 var whitespace =
    " \n\r\t\f\x0b\xa0\u2000\u2001\u2002\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200a\u200b\u2028\u2029\u3000";
  return (typeof mixed_var === 'number' || (typeof mixed_var === 'string' && whitespace.indexOf(mixed_var.slice(-1)) === -
    1)) && mixed_var !== '' && !isNaN(mixed_var);
}



function json_encode(mixed_val) {
  var retVal, json = this.window.JSON;
  try {
    if (typeof json === 'object' && typeof json.stringify === 'function') {
      retVal = json.stringify(mixed_val);
      if (retVal === undefined) {
        throw new SyntaxError('json_encode');
      }
      return retVal;
    }

    var value = mixed_val;

    var quote = function (string) {
      var escapable =
        /[\\\"\u0000-\u001f\u007f-\u009f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g;
      var meta = {
        '\b': '\\b',
        '\t': '\\t',
        '\n': '\\n',
        '\f': '\\f',
        '\r': '\\r',
        '"': '\\"',
        '\\': '\\\\'
      };

      escapable.lastIndex = 0;
      return escapable.test(string) ? '"' + string.replace(escapable, function (a) {
        var c = meta[a];
        return typeof c === 'string' ? c : '\\u' + ('0000' + a.charCodeAt(0)
          .toString(16))
          .slice(-4);
      }) + '"' : '"' + string + '"';
    };

    var str = function (key, holder) {
      var gap = '';
      var indent = '    ';
      var i = 0;
      var k = '';
      var v = '';
      var length = 0;
      var mind = gap;
      var partial = [];
      var value = holder[key];

      if (value && typeof value === 'object' && typeof value.toJSON === 'function') {
        value = value.toJSON(key);
      }

      switch (typeof value) {
      case 'string':
        return quote(value);

      case 'number':
        return isFinite(value) ? String(value) : 'null';

      case 'boolean':
      case 'null':

        return String(value);

      case 'object':
  
        if (!value) {
          return 'null';
        }
        if ((this.PHPJS_Resource && value instanceof this.PHPJS_Resource) || (window.PHPJS_Resource &&
          value instanceof window.PHPJS_Resource)) {
          throw new SyntaxError('json_encode');
        }

        gap += indent;
        partial = [];

        if (Object.prototype.toString.apply(value) === '[object Array]') {

          length = value.length;
          for (i = 0; i < length; i += 1) {
            partial[i] = str(i, value) || 'null';
          }

          v = partial.length === 0 ? '[]' : gap ? '[\n' + gap + partial.join(',\n' + gap) + '\n' + mind +
            ']' : '[' + partial.join(',') + ']';
          gap = mind;
          return v;
        }

        for (k in value) {
          if (Object.hasOwnProperty.call(value, k)) {
            v = str(k, value);
            if (v) {
              partial.push(quote(k) + (gap ? ': ' : ':') + v);
            }
          }
        }

        v = partial.length === 0 ? '{}' : gap ? '{\n' + gap + partial.join(',\n' + gap) + '\n' + mind + '}' :
          '{' + partial.join(',') + '}';
        gap = mind;
        return v;
      case 'undefined':
      case 'function':
      default:
        throw new SyntaxError('json_encode');
      }
    };

    return str('', {
      '': value
    });

  } catch (err) {
    if (!(err instanceof SyntaxError)) {
      throw new Error('Unexpected error type in json_encode()');
    }
    this.php_js = this.php_js || {};
    // usable by json_last_error()
    this.php_js.last_error_json = 4;
    return null;
  }
}

function json_decode(str_json) {
  var json = this.window.JSON;
  if (typeof json === 'object' && typeof json.parse === 'function') {
    try {
      return json.parse(str_json);
    } catch (err) {
      if (!(err instanceof SyntaxError)) {
        throw new Error('Unexpected error type in json_decode()');
      }
      this.php_js = this.php_js || {};
      this.php_js.last_error_json = 4;
      return null;
    }
  }

  var cx = /[\u0000\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g;
  var j;
  var text = str_json;
cx.lastIndex = 0;
  if (cx.test(text)) {
    text = text.replace(cx, function (a) {
      return '\\u' + ('0000' + a.charCodeAt(0)
        .toString(16))
        .slice(-4);
    });
  }
if ((/^[\],:{}\s]*$/)
    .test(text.replace(/\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})/g, '@')
      .replace(/"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g, ']')
      .replace(/(?:^|:|,)(?:\s*\[)+/g, ''))) {
j = eval('(' + text + ')');

    return j;
  }

  this.php_js = this.php_js || {};
  // usable by json_last_error()
  this.php_js.last_error_json = 4;
  return null;
}

function get_used_img(global_part){
    var used_img = [];
    $.each(global_part, function(part_id, part_data){
        if(part_data.hasOwnProperty('img_s')){
            $.each(part_data.img_s, function(){
               used_img.push(this.img_id); 
            });
        }
        if(part_data.hasOwnProperty('category')){
            $.each(part_data.category,function(){
                $.each(this.img, function(){
                    used_img.push(this.img_id); 
                });   
            });
        }
    });
    return used_img;
}

function in_array(array, id) {
    for(var i=0;i<array.length;i++) {
        if(array[i] == id){
            return true
        }
        //return (array[i] === id)
        console.log(array[i], id)
    }
    return false;
}

$(document).on('show.bs.modal', '.modal', function () { used_img = get_used_img(global_part); })

});